@@ -1443,7 +1443,7 @@ class LaharFlowData(object):
             cnorm = colors.Normalize(vmin=vmin, vmax=vmax)
         
         if clip_low:
-            data = np.ma.masked_below(data, vmin)
+            data = np.ma.masked_less(data, vmin)
 
         if ax is None:
             fig, ax = plt.subplots()
